@@ -66,7 +66,7 @@ from The Open Group.
 /* isprint() in "C" locale */
 #define c_isprint(c) ((c) >= 0x20 && (c) < 0x7f)
 
-static int term_width = 144 + 8;
+static unsigned int term_width = 144 + 8;
 
 /*
  *
@@ -145,7 +145,7 @@ static char *
 Read_Quoted (FILE *stream)
 {
     char *ptr;
-    int c, length;
+    int length;
 
     Read_White_Space(stream);
     if (Read_Char(stream)!='\'')
@@ -153,6 +153,8 @@ Read_Quoted (FILE *stream)
 
     ptr = _large_buffer; length = MAXSTR;
     for (;;) {
+	int c;
+
 	if (length < 0)
 	    Fatal_Error("Bad format file format: dformat too long.");
 	c = Read_Char(stream);
@@ -267,17 +269,16 @@ Apply_Default_Formats (const char **format, const char **dformat)
 static void
 Lookup_Formats (Atom atom, const char **format, const char **dformat)
 {
-    int i;
-
     if (_property_formats)
-	for (i = _property_formats->thunk_count-1; i >= 0; i--)
-	    if (_property_formats[i].value == atom) {
+	for (int i = _property_formats->thunk_count-1; i >= 0; i--) {
+	    if (_property_formats[i].value == (long) atom) {
 		if (!*format)
 		    *format = _property_formats[i].format;
 		if (!*dformat)
 		    *dformat = _property_formats[i].dformat;
 		break;
 	    }
+	}
 }
 
 static void
@@ -534,11 +535,13 @@ Read_Mappings (FILE *stream)
 {
     char format_buffer[100];
     char name[1000];
-    const char *dformat, *format;
-    int count, c;
-    Atom atom;
+    int count;
 
     while ((count = fscanf(stream," %990s %90s ",name,format_buffer)) != EOF) {
+	const char *dformat, *format;
+	int c;
+	Atom atom;
+
 	if (count != 2)
 	    Fatal_Error("Bad format file format.");
 
@@ -596,7 +599,7 @@ Format_Signed (long wrd)
 
 /*ARGSUSED*/
 static int
-ignore_errors (Display *dpy, XErrorEvent *ev)
+ignore_errors (Display *display, XErrorEvent *ev)
 {
     return 0;
 }
@@ -618,7 +621,7 @@ Format_Atom (Atom atom)
 	snprintf(_formatting_buffer, sizeof(_formatting_buffer),
 		 "undefined atom # 0x%lx", atom);
     else {
-	int namelen = strlen(name);
+	size_t namelen = strlen(name);
 	if (namelen > MAXSTR) namelen = MAXSTR;
 	memcpy(_formatting_buffer, name, namelen);
 	_formatting_buffer[namelen] = '\0';
@@ -630,7 +633,7 @@ Format_Atom (Atom atom)
 static const char *
 Format_Mask_Word (long wrd)
 {
-    long bit_mask, bit;
+    unsigned long bit_mask, bit;
     int seen = 0;
 
     strcpy(_formatting_buffer, "{MASK: ");
@@ -780,7 +783,6 @@ Format_Icons (const unsigned long *icon, int len)
 	unsigned long width, height, display_width;
 	unsigned int icon_pixel_bytes;
 	unsigned int icon_line_bytes;
-	int w, h;
 	int offset;
 	
 	width = *icon++;
@@ -818,11 +820,11 @@ Format_Icons (const unsigned long *icon, int len)
 	    continue;
 	}
 	
-	for (h = 0; h < height; ++h)
+	for (unsigned int h = 0; h < height; ++h)
 	{
 	    tail += sprintf (tail, "\t");
 	    
-	    for (w = 0; w < width; ++w)
+	    for (unsigned int w = 0; w < width; ++w)
 	    {
 		unsigned char a, r, g, b;
 		unsigned long pixel = *icon++;
@@ -894,7 +896,7 @@ static const char *
 Format_Len_Text (const char *string, int len, Atom encoding)
 {
     XTextProperty textprop;
-    char **list, **start_list;
+    char **start_list;
     int count;
 
     /* Try to convert to local encoding. */
@@ -903,7 +905,7 @@ Format_Len_Text (const char *string, int len, Atom encoding)
     textprop.value = (unsigned char *) string;
     textprop.nitems = len;
     if (XmbTextPropertyToTextList(dpy, &textprop, &start_list, &count) == Success) {
-	list = start_list;
+	char **list = start_list;
 	_buf_ptr = _formatting_buffer;
 	_buf_len = MAXSTR;
 	*_buf_ptr++ = '"';
@@ -977,12 +979,10 @@ static int
 is_valid_utf8 (const char *string, int len)
 {
     unsigned long codepoint = 0;
-    int rem, i;
-    unsigned char c;
+    int rem = 0;
 
-    rem = 0;
-    for (i = 0; i < len; i++) {
-	c = (unsigned char) string[i];
+    for (int i = 0; i < len; i++) {
+	 unsigned char c = (unsigned char) string[i];
 
 	/* Order of type check:
 	 *   - Single byte code point
@@ -1024,12 +1024,12 @@ is_valid_utf8 (const char *string, int len)
 static const char *
 Format_Len_Unicode (const char *string, int len)
 {
-    char *data;
-    const char *result, *error;
-
     int validity = is_valid_utf8(string, len);
 
     if (validity != UTF8_VALID) {
+	char *data;
+	const char *result, *error;
+
 	switch (validity) {
 	  case UTF8_FORBIDDEN_VALUE:
 	    error = "<Invalid UTF-8 string: Forbidden value> "; break;
@@ -1147,9 +1147,7 @@ Format_Thunk_I (thunk *thunks, const char *format, int i)
 static long
 Mask_Word (thunk *thunks, const char *format)
 {
-    int j;
-
-    for (j = 0; j  < (int)strlen(format); j++)
+    for (int j = 0; j  < (int)strlen(format); j++)
 	if (Get_Format_Char(format, j) == 'm')
 	    return thunks[j].value;
     return 0;
@@ -1403,13 +1401,13 @@ Break_Down_Property (const char *pointer, int length, Atom type, const char *for
     thunk *thunks;
     thunk t = {0};
     int i;
-    char format_char;
 
     thunks = Create_Thunk_List();
     i = 0;
 
     while (length >= size/8) {
-	format_char = Get_Format_Char(format, i);
+	char format_char = Get_Format_Char(format, i);
+
 	if (format_char == 's' || format_char == 'u')
 	    t.value = Extract_Len_String(&pointer,&length,size,&t.extra_value);
 	else if (format_char == 't') {
@@ -1447,11 +1445,9 @@ static const char *
 Get_Font_Property_Data_And_Type (Atom atom,
                                  long *length, Atom *type, int *size)
 {
-    int i;
-	
     *type = None;
 	
-    for (i = 0; i < font->n_properties; i++)
+    for (int i = 0; i < font->n_properties; i++)
 	if (atom == font->properties[i].name) {
 	    _font_prop = font->properties[i].card32;
 	    *length = sizeof(long);
@@ -1508,7 +1504,7 @@ Get_Window_Property_Data_And_Type (Atom atom,
 static const char *
 Get_Property_Data_And_Type (Atom atom, long *length, Atom *type, int *size)
 {
-    if (target_win == -1)
+    if (target_win == (Window) -1)
 	return Get_Font_Property_Data_And_Type(atom, length, type, size);
     else
 	return Get_Window_Property_Data_And_Type(atom, length, type, size);
@@ -1559,23 +1555,21 @@ Show_Prop (const char *format, const char *dformat, const char *prop)
 static void
 Show_All_Props (void)
 {
-    Atom *atoms, atom;
-    const char *name;
-    int count, i;
-
-    if (target_win != -1) {
-	atoms = XListProperties(dpy, target_win, &count);
-	for (i = 0; i < count; i++) {
-	    name = Format_Atom(atoms[i]);
+    if (target_win != (Window) -1) {
+	int count;
+	Atom *atoms = XListProperties(dpy, target_win, &count);
+	for (int i = 0; i < count; i++) {
+	    const char *name = Format_Atom(atoms[i]);
 	    Show_Prop(NULL, NULL, name);
 	}
 	XFree(atoms);
-    } else
-	for (i = 0; i < font->n_properties; i++) {
-	    atom = font->properties[i].name;
-	    name = Format_Atom(atom);
+    } else {
+	for (int i = 0; i < font->n_properties; i++) {
+	    Atom atom = font->properties[i].name;
+	    const char *name = Format_Atom(atom);
 	    Show_Prop(NULL, NULL, name);
 	}
+    }
 }
 
 static thunk *
@@ -1621,20 +1615,20 @@ Handle_Prop_Requests (int argc, char **argv)
 }
 
 static void
-Remove_Property (Display *dpy, Window w, const char *propname)
+Remove_Property (Display *display, Window w, const char *propname)
 {
-    Atom id = XInternAtom (dpy, propname, True);
+    Atom id = XInternAtom (display, propname, True);
 
     if (id == None) {
 	fprintf (stderr, "%s:  no such property \"%s\"\n",
 		 program_name, propname);
 	return;
     }
-    XDeleteProperty (dpy, w, id);
+    XDeleteProperty (display, w, id);
 }
 
 static void
-Set_Property (Display *dpy, Window w, const char *propname, const char *value)
+Set_Property (Display *display, Window w, const char *propname, const char *value)
 {
     Atom atom;
     const char *format;
@@ -1666,7 +1660,7 @@ Set_Property (Display *dpy, Window w, const char *propname, const char *value)
       case 'u':
 	if (size != 8)
 	    Fatal_Error("can't use format character 'u' with any size except 8.");
-	type = XInternAtom(dpy, "UTF8_STRING", False);
+	type = XInternAtom(display, "UTF8_STRING", False);
 	data = (const unsigned char *) value;
 	nelements = strlen(value);
 	break;
@@ -1674,7 +1668,7 @@ Set_Property (Display *dpy, Window w, const char *propname, const char *value)
 	XTextProperty textprop;
 	if (size != 8)
 	    Fatal_Error("can't use format character 't' with any size except 8.");
-	if (XmbTextListToTextProperty(dpy, (char **) &value, 1,
+	if (XmbTextListToTextProperty(display, (char **) &value, 1,
 				      XStdICCTextStyle, &textprop) != Success) {
 	    fprintf(stderr, "cannot convert %s argument to STRING or COMPOUND_TEXT.\n", propname);
 	    return;
@@ -1804,7 +1798,7 @@ Set_Property (Display *dpy, Window w, const char *propname, const char *value)
 	Fatal_Error("bad format character: %c", format_char);
     }
 
-    XChangeProperty(dpy, target_win, atom, type, size, PropModeReplace,
+    XChangeProperty(display, target_win, atom, type, size, PropModeReplace,
 		    data, nelements);
 }
 
@@ -1814,7 +1808,7 @@ Set_Property (Display *dpy, Window w, const char *propname, const char *value)
  *
  */
 
-void
+static void
 print_help (void)
 {
     static const char *help_message =
@@ -1845,12 +1839,14 @@ print_help (void)
     fprintf (stderr, "%s\n", help_message);
 }
 
-void help (void) {
+static inline void _X_NORETURN _X_COLD
+help (void)
+{
 	print_help();
 	exit(0);
 }
 
-void
+void _X_NORETURN _X_COLD
 usage (const char *errmsg)
 {
     if (errmsg != NULL)
@@ -1860,7 +1856,7 @@ usage (const char *errmsg)
     exit (1);
 }
 
-static void
+static void _X_NORETURN _X_COLD
 grammar (void)
 {
     printf ("Grammar for xprop:\n\n");
@@ -1890,7 +1886,7 @@ Parse_Format_Mapping (int *argc, char ***argv)
 #define ARGC (*argc)
 #define ARGV (*argv)
 #define OPTION ARGV[0]
-#define NXTOPT if (++ARGV, --ARGC==0) usage("insufficent arguments for -format")
+#define NXTOPT if (++ARGV, --ARGC==0) usage("insufficient arguments for -format")
     char *type_name, *format, *dformat;
   
     NXTOPT; type_name = OPTION;
@@ -1915,9 +1911,9 @@ Parse_Format_Mapping (int *argc, char ***argv)
 
 static int spy = 0;
 
-static int (*old_error_handler)(Display *dpy, XErrorEvent *ev);
+static int (*old_error_handler)(Display *display, XErrorEvent *ev);
 
-static int spy_error_handler(Display *dpy, XErrorEvent *ev)
+static int spy_error_handler(Display *display, XErrorEvent *ev)
 {
     if (ev->error_code == BadWindow || ev->error_code == BadMatch) {
 	/* Window was destroyed */
@@ -1926,7 +1922,7 @@ static int spy_error_handler(Display *dpy, XErrorEvent *ev)
     }
 
     if (old_error_handler)
-	return old_error_handler(dpy, ev);
+	return old_error_handler(display, ev);
 
     return 0;
 }
@@ -2012,7 +2008,7 @@ main (int argc, char **argv)
 	if (!strcmp(argv[0], "-font")) {
 	    if (++argv, --argc == 0) usage("-font requires an argument");
 	    font = Open_Font(argv[0]);
-	    target_win = -1;
+	    target_win = (Window) -1;
 	    continue;
 	}
 	if (!strcmp(argv[0], "-remove")) {
@@ -2025,7 +2021,7 @@ main (int argc, char **argv)
 	}
 	if (!strcmp(argv[0], "-set")) {
 	    thunk t = {0};
-	    if (argc < 3) usage("insufficent arguments for -set");
+	    if (argc < 3) usage("insufficient arguments for -set");
 	    t.propname = argv[1];
 	    t.extra_value = argv[2];
 	    argv += 3; argc -= 3;
@@ -2062,7 +2058,7 @@ main (int argc, char **argv)
     if (remove_props != NULL) {
 	int count;
 
-	if (target_win == -1)
+	if (target_win == (Window) -1)
 	    Fatal_Error("-remove works only on windows, not fonts");
 
 	count = remove_props->thunk_count;
@@ -2073,7 +2069,7 @@ main (int argc, char **argv)
     if (set_props != NULL) {
 	int count;
 
-	if (target_win == -1)
+	if (target_win == (Window) -1)
 	    Fatal_Error("-set works only on windows, not fonts");
 
 	count = set_props->thunk_count;
@@ -2089,7 +2085,7 @@ main (int argc, char **argv)
 
     props = Handle_Prop_Requests(argc, argv);
 
-    if (spy && target_win != -1) {
+    if (spy && target_win != (Window) -1) {
 	XEvent event;
 	const char *format, *dformat;
 	
@@ -2106,7 +2102,7 @@ main (int argc, char **argv)
 	    if (props) {
 		int i;
 		for (i = 0; i < props->thunk_count; i++)
-		    if (props[i].value == event.xproperty.atom)
+		    if (props[i].value == (long) event.xproperty.atom)
 			break;
 		if (i >= props->thunk_count)
 		    continue;
